# LéXPLORE Surface Waves

## Project Information

[LéXPLORE](https://lexplore.info) is research platform on Lake Geneva for a broad range of limnological research. The platform results from a collaboration between five partner institutions ([Eawag](https://www.eawag.ch/en/), [EPFL](https://www.epfl.ch/en/), [INRAE](https://www6.lyon-grenoble.inrae.fr/carrtel/), [UNIGE](https://unige.ch), [UNIL](https://www.unil.ch/index.html)). The LéXPLORE platform is anchored since February 2019 at a position reaching 110 m depth off the lake's north-shore.
The data presented here is part of the core dataset maintained by the technical team of LéXPLORE.
The data is used and displayed on the [Datalakes website](https://www.datalakes-eawag.ch/). related data or products can be visualised and downloaded on the [Datalakes website](https://www.datalakes-eawag.ch/).

**References**:

Wüest, A., Bouffard, D., Guillard, J., Ibelings, B. W., Lavanchy, S., Perga, M. ‐E., & Pasche, N. (2021). LéXPLORE: a floating laboratory on Lake Geneva offering unique lake research opportunities. Wiley Interdisciplinary Reviews: Water, 8(5), e1544 (15 pp.). https://doi.org/10.1002/wat2.1544

See also the [360° virtual tour](https://www.eawag.ch/repository/lexplore/index.htm)


## Citation
Bouffard, D., Cunillera, G, Fillon, R., Gios, M., Guillard, J., Ibelings, B., Lavanchy, S., Miesen, F., Pasche, N., Perga, M-E., Plüss, M., Quetin, P., Runnalls, J. (2022). Surface waves data and products from LéXPLORE platform,  2022. DOI

DOI attribution pending.


## Sensors

The surface waves databuoy records at 60 minute intervals the surface waves characteristics (height, period, direction). 
The buoy is located 60 m away (NE) from the platform (46°30′02.311″N 6°39′41.261″E) 
The system is based on a MEMS (microelectromechanical system) technology that accounts for 3D motion, rotation, compass and heading in all dimensions.

### Surface waves (height, period, direction)
- **Brand, Model & SN**:    SeaView wave sensor, SVS603, SN wave01055
- **System integration**:   Sensor integrated in a Nexsens CB-450 databuoy, Nexsens X2 datalogger with 2.4Ghz radio telemetry
- **Accuracy**:             Significant wave height  (Hs): 1cm @ 0.1m; 2cm @ 1.5m; 10cm @ 25m
                            Period: 0.02sec @ 1sec; 0.04sec @ 2sec; 0.1sec @ 20sec
                            Wave direction: ±4 degrees 
- **Setup**:                sampling period: one datapoint every 60 min(17 min of measurement).  

## Installation

:warning You need to have [git](https://git-scm.com/downloads) and [git-lfs](https://git-lfs.github.com/) installed in order to successfully clone the repository.

- Clone the repository to your local machine using the command: 

 `git clone https://renkulab.io/gitlab/lexplore/wave-buoy.git`
 
 Note that the repository will be copied to your current working directory.

- Use Python 3 and install the requirements with:

 `pip install -r requirements.txt`

 The python version can be checked by running the command `python --version`. In case python is not installed or only an older version of it, it is recommend to install python through the anaconda distribution which can be downloaded [here](https://www.anaconda.com/products/individual). 

## Usage

### Process new data

In order to process new data locally on your machine the file path needs to be adapted to your local file system. The following steps are therefore necessary: 

- Edit the `scripts/input_batch.bat` file. Change all the directory paths to match your local file system. This file contains all the file paths necessary to launch the batch scripts `runfile.bat`.

- Edit the `scripts/input_python.py` file. Change all the directory paths to match your local file system. This file contains all the directories where the python script outputs data to.

To process new data, place the data in the input directory which you specified in the `scripts/input_batch.bat` file. Double-clicking on the `runfile.bat` file will automatically 
process all the data in the input directory and store the output in the directories specified in the `scripts/input_python.py` file. 

### Adapt/Extend data processing pipeline

The python script `scripts/main.py` defines the different processing steps while the python script `scripts/surfacewaves.py` contains the python class surfacewaves with all the corresponding 
class methods to process the data. To add a new processing or visualization step, a new class method can be created in the `surfacewaves.py` file and the step can be added in `main.py` file.
Both above mentioned python scripts are independent of the local file system.

## Data

The data can be found in the folder `data`. The data is structured as follows:

### Data Structure

- **Level 0**: Raw data collected from the different sensors.

- **Level 1**: Raw data stored to NetCDF file where attributes (such as sensors used, units, description of data, etc.) are added to the data, column with quality flags are added to the Level 1A data. Quality flag "1" indicates that the data point didn't pass the 
quality checks and further investigation is needed, quality flag "0" indicates that no further investiagion is needed.

## Quality assurance

Quality checks include but are not limited to range validation, data type checking and flagging missing data. Full details can be seen in the quality_assurance.json file.
Advanced quality assurance can be run using the `scripts/quality_assurance.py` function. In order to better define the quality assurance users can interact with the data and define
new quality assurance checks in `notebooks/define_quality assurance.ipynb`.



###  Events 

Maintenance dates, interesting or surprising events, non identified by the quality assurance outliers are listed in the folder `events`.
Check also the `sensor_history` (if existing)

## Collaborators

- **Concept, finances, project management** Damien Bouffard, Jean Guillard, Bas Ibelings, Natacha Pasche, Marie-Elodie Perga   
- **Installation, maintenance, data collection** Guillaume Cunillera, Mateo Gios, Roxane Fillon, Sébastien Lavanchy, Floreana Miesen, Michael Plüss, Philippe Quetin
- **Data pipeline** Damien Bouffard, James Runnalls
- **Data review** Damien Bouffard
- **Contact tech** Sébastien Lavanchy 
- **Contact science** Damien Bouffard

